package com.ejie.ab61.control.parametros;

import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab61.model.parametros.Parametros;
import com.ejie.ab61.model.usuario.Usuario;
import com.ejie.ab61.service.parametros.ParametrosService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;

/**
 * ParametrosController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/parametros")

public class ParametrosController {

	private static final Logger logger = LoggerFactory.getLogger(ParametrosController.class);

	@Autowired
	private ParametrosService parametrosService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idParametro
	 *            Integer
	 * @return Parametros Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idParametro}", method = RequestMethod.GET)
	public @ResponseBody Parametros get(@PathVariable Integer idParametro) {
		Parametros parametros = new Parametros();
		parametros.setIdParametro(idParametro);
		parametros = this.parametrosService.find(parametros);
		ParametrosController.logger.info("[GET - findBy_PK] : Obtener Parametros por PK");
		return parametros;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterParametros
	 *            Parametros Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Parametros> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Parametros> getAll(@ModelAttribute Parametros filterParametros) {
		ParametrosController.logger.info("[GET - find_ALL] : Obtener Parametros por filtro");
		return this.parametrosService.findAll(filterParametros, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param parametros
	 *            Parametros Bean que contiene la informacion a modificar.
	 * @return Parametros Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Parametros edit(@RequestBody Parametros parametros,
			@ModelAttribute(value = "usuario") Usuario usuario) {
		parametros.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		Parametros parametrosAux = this.parametrosService.update(parametros);
		ParametrosController.logger.info("[PUT] : Parametros actualizado correctamente");
		return parametrosAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param parametros
	 *            Parametros Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Parametros Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Parametros add(@RequestBody Parametros parametros,
			@ModelAttribute(value = "usuario") Usuario usuario) {
		parametros.setUsuarioRegistro(usuario.getNombreUsuario());
		Parametros parametrosAux = this.parametrosService.add(parametros);
		ParametrosController.logger.info("[POST] : Parametros insertado correctamente");
		return parametrosAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idParametro
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Parametros Bean eliminado.
	 */
	@RequestMapping(value = "/{idParametro}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Parametros remove(@PathVariable Integer idParametro) {
		Parametros parametros = new Parametros();
		parametros.setIdParametro(idParametro);
		this.parametrosService.remove(parametros);
		ParametrosController.logger.info("[DELETE] : Parametros borrado correctamente");
		return parametros;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		ParametrosController.logger.info("[GET - View] : parametros");
		return "parametros";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterParametros
	 *            Parametros Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Parametros> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Parametros> filter(
			@RequestJsonBody(param = "filter") Parametros filterParametros,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ParametrosController.logger.info("[POST - filter] : Obtener Parametross");
		return this.parametrosService.filter(filterParametros, jqGridRequestDto, false);
	}
}
